--Bar Class

--Control that contains a window as a border, interior shading and a bar.

--[[Bar.	Window			Object
			Background		Object
			Bar					Object
			Data.				x,y						Location
									sx,sy					Size
									BorderWidth		Width of Border
									Orient					Orientation l,r,u,d (fill direction - which edge does it empty towards?)]]--

Bar=class(Turbine.UI.Control)

function Bar:Constructor()
	
	self.Data={}
	
--Window is the basis for the two controls
	self.Window=Turbine.UI.Window()
	self.Window:SetVisible(true)
	self.Window:SetMouseVisible(false)
	
--Background Control
	self.Background=Turbine.UI.Control()
	self.Background:SetParent(self.Window)
	self.Background:SetVisible(true)
	self.Background:SetMouseVisible(false)
	
--Bar Control
	self.Bar=Turbine.UI.Control()
	self.Bar:SetParent(self.Window)
	self.Bar:SetVisible(true)
	self.Bar:SetMouseVisible(false)
	
--TextBox
	self.Text=Turbine.UI.Label()
      self.Text:SetParent( self.Window )
      self.Text:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleCenter )
	  self.Text:SetOutlineColor( Turbine.UI.Color(1, 0, 0, 0 ) )
	  self.Text:SetFont(Turbine.UI.Lotro.Font[Option.Font])
	  self.Text:SetFontStyle( Turbine.UI.FontStyle.Outline )
	  self.Text:SetMouseVisible(false)
	
--Dragbar including Rotator
	self.Window.DragBar = Deusdictum.UI.DragBar( self.Window,"Drag Bar")
	self.Window.DragBar:SetRotator( true )
	self.Window.DragBar:SetRotatorOffset(20, 20)
	self.Window.RotateStart = function () self:Rotate() end
	
	self.Window.MouseDown  =function(sender,args)
		if self.Window.DragBar:IsVisible() then
			Moving=true
		end
	end
	
	self.Window.MouseUp =function(sender,args)
		
		if Moving then 
			Moving=false
		end
		
	end
	
	self.Window.MouseMove = function(sender,args)
		if Moving then
			local x,y=self.Window:GetMousePosition()
			if x<5 then x=5 end
			if y<5 then y=5 end
			--If the alt key is down round the size to the nearest 5px
			if self.Window:IsAltKeyDown() and not(loading) then
				x=math.ceil(x/5)*5 y=math.ceil(y/5)*5
			end

			self:SetSize(x,y)
			
			self:SetFill(0.8) self:SetOpacity(1) 
			self.Window.DragBar:Refresh()
		end
	end
	
	self.Window.PositionChanged=function (sender,args)
		--If the alt key is being held down then snap to a background grid that is 16x16
		if self.Window:IsAltKeyDown() and not(loading) then
			local x,y=self.Window:GetPosition()
			x=math.ceil(x/16)*16 y=math.ceil(y/16)*16
			return self:SetPosition(x,y)
		end
	end
end

function Bar:SetMouseVisible(n)
	self.Window:SetMouseVisible(n)
end

function Bar:SetName(s)
	--Mainly just keyed into DragBar.
	self.Data.name=s
	self.Window.DragBar.sName=s
	self.Window.DragBar.Label:SetText( s )
end

function Bar:SetSize(sx,sy)
	self.Data.sx,self.Data.sy=sx,sy
	self.Window:SetSize(sx,sy)
	self.Background:SetSize(sx,sy)
	self:Refresh()
	self.Window.DragBar:Refresh()
	self.Text:SetSize(sx,sy)
end

function Bar:SetPosition(x,y)
	self.Window:SetPosition(x,y)
	self.Data.x,self.Data.y=x,y
	self.Window.DragBar:Refresh()
end

function Bar:SetText(s)
	self.Text:SetText( s)
end


function Bar:GetPosition()
	self.Data.x,self.Data.y=self.Window:GetPosition()
	return self.Data.x,self.Data.y
end

function Bar:SetFill(n)
	local o=self.Data.Orient or "l"
	local width=self.Data.BorderWidth or 2
	self.Data.Fill=n
	if o=="l" or o=="r" then
		x=self.Data.sx*n-2*width y=self.Data.sy-2*width
	else
		x=self.Data.sx-2*width y=self.Data.sy*n-2*width
	end
	
	self.Bar:SetSize(x,y)
	self:RefreshBar()
	--Scaled opacity.
		n=(1-n)*(1/Option.Opacity)
		if Option.Opacity==0 then n=1 end
		if n>1 then n=1 end
		self:SetOpacity(n) 
	--end
end

function Bar:RefreshBar()
	local o=self.Data.Orient or "l"
	local width=self.Data.BorderWidth or 2
	local x,y=self.Bar:GetSize()
	if 			o=="l" then
		self.Bar:SetPosition(width,width)
	elseif 	o=="r" then
		self.Bar:SetPosition(self.Window:GetWidth()-x-width,width)
	elseif	o=="u" then
		self.Bar:SetPosition(width,width)
	elseif	o=="d" then
		self.Bar:SetPosition(width,self.Window:GetHeight()-y-width)
	end
end

function Bar:Rotate()
	local o=self.Data.Orient or "l"
	local w,h=self.Window:GetSize()
	local bw,bh=self.Bar:GetSize()
	
	if 	o=="l" then
			o="r" 
	elseif 	o=="r" then
			o="u"	self:SetSize(h,w) self.Bar:SetSize(bh,bw)
	elseif	o=="u" then
			o="d"
	elseif	o=="d" then
			o="l"	self:SetSize(h,w)  self.Bar:SetSize(bh,bw)
	end
	self:Orient(o)
	self:Refresh()
end

function Bar:Orient(n)
	self.Data.Orient=n
	self:RefreshBar()
end

function Bar:SetBorderColor(n)
	self.Window:SetBackColor(n)
end

function Bar:SetBorderWidth(n)
	self.Data.BorderWidth=n or 2
	self:Refresh()
end

function Bar:Refresh()
	local width=self.Data.BorderWidth or 2
	self.Background:SetSize(self.Window:GetWidth()-2*width,self.Window:GetHeight()-2*width)
	self.Background:SetPosition(width,width)
	self:RefreshBar()
end
function Bar:SetBackgroundColor(n)
	self.Background:SetBackColor(n)
end
function Bar:SetBarColor(n)
	self.Bar:SetBackColor(n)
end
function Bar:SetOpacity(n)
	self.Window:SetOpacity(n)
end
function Bar:GetOpacity()
	return self.Window:GetOpacity()
end
